hookee Coverage Report

# hookee Coverage Report: 93.07%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 736 | 51 | 2 | 93.07%
hookee/__init__.py | 1 | 0 | 0 | 100.00%
hookee/cli.py | 106 | 6 | 2 | 94.34%
hookee/conf.py | 55 | 6 | 0 | 89.09%
hookee/exception.py | 9 | 0 | 0 | 100.00%
hookee/hookeemanager.py | 78 | 14 | 0 | 82.05%
hookee/pluginmanager.py | 141 | 10 | 0 | 92.91%
hookee/plugins/__init__.py | 0 | 0 | 0 | 100.00%
hookee/plugins/blueprint_default.py | 31 | 0 | 0 | 100.00%
hookee/plugins/request_body.py | 20 | 1 | 0 | 95.00%
hookee/plugins/request_files.py | 14 | 1 | 0 | 92.86%
hookee/plugins/request_headers.py | 16 | 0 | 0 | 100.00%
hookee/plugins/request_query_params.py | 14 | 0 | 0 | 100.00%
hookee/plugins/request_url_info.py | 17 | 0 | 0 | 100.00%
hookee/plugins/response_echo.py | 23 | 0 | 0 | 100.00%
hookee/plugins/response_info.py | 19 | 0 | 0 | 100.00%
hookee/server.py | 60 | 3 | 0 | 95.00%
hookee/tunnel.py | 67 | 6 | 0 | 91.04%
hookee/util.py | 65 | 4 | 0 | 93.85%

No items found using the specified filter.